@@ -1,9 +1,9 @@
 /*
- *	$Id: access.c,v 1.7 2000/04/21 11:58:00 mj Exp $
+ *	$Id: access.c,v 1.10 2003/01/04 11:04:39 mj Exp $
  *
  *	The PCI Library -- User Access
  *
- *	Copyright (c) 1997--1999 Martin Mares <mj@atrey.karlin.mff.cuni.cz>
+ *	Copyright (c) 1997--1999 Martin Mares <mj@ucw.cz>
  *
  *	Can be freely distributed and used under the terms of the GNU GPL.
  */
@@ -22,11 +22,6 @@ static struct pci_methods *pci_methods[PCI_ACCESS_MAX] = {
 #else
   NULL,
 #endif
-#ifdef HAVE_PM_SYSCALLS
-  &pm_syscalls,
-#else
-  NULL,
-#endif
 #ifdef HAVE_PM_INTEL_CONF
   &pm_intel_conf1,
   &pm_intel_conf2,
@@ -44,6 +39,11 @@ static struct pci_methods *pci_methods[PCI_ACCESS_MAX] = {
 #else
   NULL,
 #endif
+#ifdef HAVE_PM_NBSD_LIBPCI
+  &pm_nbsd_libpci,
+#else
+  NULL,
+#endif
 #ifdef HAVE_PM_DUMP
   &pm_dump,
 #else
